@@ -1,3 +1,5 @@
+import warnings
+from typing_extensions import deprecated
 from typing import List, Optional, Sequence
 
 from httpx import Response
@@ -6,16 +8,107 @@ from tsugu_api_core import settings
 from tsugu_api_core._network import Api
 from tsugu_api_core._typing import (
     _Room,
-    _Server,
+    Server,
+    ServerId,
     _Response,
-    _DifficultyText
+    _DifficultyId,
+    FuzzySearchResult,
+    _FuzzySearchResponse
 )
 
-async def event_stage(server: _Server, event_id: Optional[int] = None, meta: bool = False) -> _Response:
+async def cutoff_all(main_server: ServerId, event_id: Optional[int] = None) -> _Response:
+    '''查询活动排行榜全部预测线
+
+    参数:
+        main_server (_ServerId): 主服务器
+        event_id (int): 活动 ID
+
+    返回:
+        _Response: 响应信息
+    '''
+    
+    # 构建数据
+    data = {
+        'mainServer': main_server,
+        'compress': settings.compress
+    }
+    if event_id:
+        data['eventId'] = event_id
+    
+    # 发送请求
+    response = await Api(
+        settings.backend_url,
+        '/cutoffAll',
+        proxy=settings.backend_proxy
+    ).apost(data)
+    if isinstance(response, Response): return response.json()
+    return await response.json()
+
+async def cutoff_detail(main_server: ServerId, tier: int, event_id: Optional[int] = None) -> _Response:
+    '''查询活动排行榜预测线
+
+    参数:
+        main_server (_ServerId): 主服务器
+        tier (int): 排行榜挡位
+        event_id (int): 活动 ID
+
+    返回:
+        _Response: 响应信息
+    '''
+    
+    # 构建数据
+    data = {
+        'mainServer': main_server,
+        'tier': tier,
+        'compress': settings.compress
+    }
+    if event_id:
+        data['eventId'] = event_id
+    
+    # 发送请求
+    response = await Api(
+        settings.backend_url,
+        '/cutoffDetail',
+        proxy=settings.backend_proxy
+    ).apost(data)
+    if isinstance(response, Response): return response.json()
+    return await response.json()
+
+async def cutoff_list_of_recent_event(main_server: ServerId, tier: int, event_id: Optional[int] = None) -> _Response:
+    '''查询历史活动排行榜预测线
+
+    参数:
+        main_server (_ServerId): 主服务器
+        tier (int): 排行榜挡位
+        event_id (int): 活动 ID
+
+    返回:
+        _Response: 响应信息
+    '''
+    
+    # 构建数据
+    data = {
+        'mainServer': main_server,
+        'tier': tier,
+        'compress': settings.compress
+    }
+    if event_id:
+        data['eventId'] = event_id
+    
+    # 发送请求
+    response = await Api(
+        settings.backend_url,
+        '/cutoffListOfRecentEvent',
+        proxy=settings.backend_proxy
+    ).apost(data)
+    if isinstance(response, Response): return response.json()
+    return await response.json()
+
+async def event_stage(main_server: ServerId, event_id: Optional[int] = None, meta: bool = False) -> _Response:
     '''查询团队 LIVE 佳节活动舞台数据
 
     参数:
-        server (_Server): 服务器
+        main_server (_ServerId): 主服务器
         event_id (int): 活动 ID
         meta (bool): 是否携带歌曲分数表
 
@@ -23,12 +116,9 @@ async def event_stage(server: _Server, event_id: Optional[int] = None, meta: boo
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/eventStage'
-    
     # 构建数据
     data = {
-        'server': server,
+        'mainServer': main_server,
         'meta': meta,
         'compress': settings.compress
     }
@@ -37,17 +127,43 @@ async def event_stage(server: _Server, event_id: Optional[int] = None, meta: boo
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/eventStage',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def gacha_simulate(server_mode: _Server, times: Optional[int] = None, gacha_id: Optional[int] = None) -> _Response:
+async def fuzzy_search(text: str) -> _FuzzySearchResponse:
+    '''模糊搜索
+
+    参数:
+        text (str): 搜索文本
+
+    返回:
+        _FuzzySearchResponse: 响应信息
+    '''
+    
+    # 构建数据
+    data = {
+        'text': text,
+        'compress': settings.compress
+    }
+    
+    # 发送请求
+    response = await Api(
+        settings.backend_url,
+        '/fuzzySearch',
+        proxy=settings.backend_proxy
+    ).apost(data)
+    if isinstance(response, Response): return response.json()
+    return await response.json()
+
+async def gacha_simulate(main_server: ServerId, times: Optional[int] = None, gacha_id: Optional[int] = None) -> _Response:
     '''模拟抽卡
 
     参数:
-        server_mode (_Server): 服务器模式
+        main_server (_ServerId): 主服务器
         times (int): 抽卡次数
         gacha_id (int): 卡池 ID
 
@@ -55,12 +171,9 @@ async def gacha_simulate(server_mode: _Server, times: Optional[int] = None, gach
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/gachaSimulate'
-    
     # 构建数据
     data = {
-        'server_mode': server_mode,
+        'mainServer': main_server,
         'compress': settings.compress
     }
     if times:
@@ -70,7 +183,8 @@ async def gacha_simulate(server_mode: _Server, times: Optional[int] = None, gach
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/gachaSimulate',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
@@ -86,9 +200,6 @@ async def get_card_illustration(card_id: int) -> _Response:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/getCardIllustration'
-    
     # 构建数据
     data = {
         'cardId': str(card_id)
@@ -96,13 +207,15 @@ async def get_card_illustration(card_id: int) -> _Response:
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/getCardIllustration',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def lsycx(server: _Server, tier: int, event_id: Optional[int] = None) -> _Response:
+@deprecated("The `lsycx` api is now deprecated, use `cutoff_list_of_recent_event` instead.", category=None)
+async def lsycx(server: Server, tier: int, event_id: Optional[int] = None) -> _Response:
     '''查询历史排行榜预测线
 
     参数:
@@ -113,26 +226,15 @@ async def lsycx(server: _Server, tier: int, event_id: Optional[int] = None) -> _
     返回:
         _Response: 响应信息
     '''
+    warnings.warn(
+        "The `lsycx` api is now deprecated, use `cutoff_list_of_recent_event` instead.",
+        DeprecationWarning
+    )
     
-    # 构建 URL
-    url = settings.backend_url + '/lsycx'
+    if not isinstance(server, int):
+        raise ValueError("'server' must be an integer.")
     
-    # 构建数据
-    data = {
-        'server': server,
-        'tier': tier,
-        'compress': settings.compress
-    }
-    if event_id:
-        data['eventId'] = event_id
-    
-    # 发送请求
-    response = await Api(
-        url,
-        proxy=settings.backend_proxy
-    ).apost(data)
-    if isinstance(response, Response): return response.json()
-    return await response.json()
+    return await cutoff_list_of_recent_event(server, tier, event_id)
 
 async def room_list(room_list: List[_Room]) -> _Response:
     '''绘制车牌绘图
@@ -144,9 +246,6 @@ async def room_list(room_list: List[_Room]) -> _Response:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/roomList'
-    
     # 构建数据
     data = {
         'roomList': room_list,
@@ -155,118 +254,137 @@ async def room_list(room_list: List[_Room]) -> _Response:
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/roomList',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def search_card(default_servers: Sequence[_Server], text: str) -> _Response:
+async def search_card(
+    displayed_server_list: Sequence[ServerId],
+    text: Optional[str] = None,
+    fuzzy_search_result: Optional[FuzzySearchResult] = None
+) -> _Response:
     '''查询卡片
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        text (str): 查询参数
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
 
     返回:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/searchCard'
-    
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'text': text,
+        'displayedServerList': displayed_server_list,
         'useEasyBG': settings.use_easy_bg,
         'compress': settings.compress
     }
+    if text:
+        data['text'] = text
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/searchCard',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def search_character(default_servers: Sequence[_Server], text: str) -> _Response:
+async def search_character(
+    displayed_server_list: Sequence[ServerId],
+    fuzzy_search_result: Optional[FuzzySearchResult] = None,
+    text: Optional[str] = None
+) -> _Response:
     '''查询角色
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        text (str): 查询参数
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
 
     返回:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/searchCharacter'
-    
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'text': text,
+        'displayedServerList': displayed_server_list,
         'compress': settings.compress
     }
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
+    if text:
+        data['text'] = text
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/searchCharacter',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def search_event(default_servers: Sequence[_Server], text: str) -> _Response:
+async def search_event(
+    displayed_server_list: Sequence[ServerId],
+    fuzzy_search_result: Optional[FuzzySearchResult] = None,
+    text: Optional[str] = None
+) -> _Response:
     '''查询活动
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        text (str): 查询参数
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
 
     返回:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/searchEvent'
-    
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'text': text,
+        'displayedServerList': displayed_server_list,
         'useEasyBG': settings.use_easy_bg,
         'compress': settings.compress
     }
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
+    if text:
+        data['text'] = text
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/searchEvent',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def search_gacha(default_servers: Sequence[_Server], gacha_id: int) -> _Response:
+async def search_gacha(
+    displayed_server_list: Sequence[ServerId],
+    gacha_id: int
+) -> _Response:
     '''查询卡池
 
     参数:
-        default_servers (list[_Server]): 默认服务器
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
         gacha_id (int): 卡池 ID
 
     返回:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/searchGacha'
-    
     # 构建数据
     data = {
-        'default_servers': default_servers,
+        'displayedServerList': displayed_server_list,
         'gachaId': gacha_id,
         'useEasyBG': settings.use_easy_bg,
         'compress': settings.compress
@@ -274,132 +392,177 @@ async def search_gacha(default_servers: Sequence[_Server], gacha_id: int) -> _Re
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/searchGacha',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def search_player(player_id: int, server: _Server) -> _Response:
+async def search_player(player_id: int, main_server: ServerId) -> _Response:
     '''查询玩家状态
 
     参数:
         player_id (int): 玩家 ID
-        server (_Server): 服务器
+        main_server (_ServerId): 服务器
 
     返回:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/searchPlayer'
-    
     # 构建数据
     data = {
         'playerId': player_id,
-        'server': server,
+        'mainServer': main_server,
         'useEasyBG': settings.use_easy_bg,
         'compress': settings.compress
     }
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/searchPlayer',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def search_song(default_servers: Sequence[_Server], text: str) -> _Response:
+async def search_song(
+    displayed_server_list: Sequence[ServerId],
+    fuzzy_search_result: Optional[FuzzySearchResult] = None,
+    text: Optional[str] = None
+) -> _Response:
     '''查询歌曲
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        text (str): 查询参数
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
 
     返回:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/searchSong'
-    
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'text': text,
+        'displayedServerList': displayed_server_list,
         'compress': settings.compress
     }
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
+    if text:
+        data['text'] = text
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/searchSong',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def song_chart(default_servers: Sequence[_Server], song_id: int, difficulty_text: _DifficultyText) -> _Response:
+async def song_chart(
+    displayed_server_list: Sequence[ServerId],
+    song_id: int,
+    difficulty_id: _DifficultyId
+) -> _Response:
     '''查询歌曲谱面
 
     参数:
-        default_servers (list[_Server]): 默认服务器
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
         song_id (int): 歌曲 ID
-        difficulty_text (_Difficulty): 谱面难度
+        difficulty_id (_DifficultyId): 难度 ID
 
     返回:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/songChart'
-    
     # 构建数据
     data = {
-        'default_servers': default_servers,
+        'displayedServerList': displayed_server_list,
         'songId': song_id,
-        'difficultyText': difficulty_text,
+        'difficultyId': difficulty_id,
         'compress': settings.compress
     }
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/songChart',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def song_meta(default_servers: Sequence[_Server], server: _Server) -> _Response:
+async def song_meta(
+    displayed_server_list: Sequence[ServerId],
+    main_server: ServerId
+) -> _Response:
     '''查询歌曲分数表
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        server (_Server): 主服务器
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        main_server (_ServerId): 主服务器
 
     返回:
         _Response: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.backend_url + '/songMeta'
-    
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'server': server,
+        'displayedServerList': displayed_server_list,
+        'mainServer': main_server,
         'compress': settings.compress
     }
     
     # 发送请求
     response = await Api(
-        url,
+        settings.backend_url,
+        '/songMeta',
         proxy=settings.backend_proxy
     ).apost(data)
     if isinstance(response, Response): return response.json()
     return await response.json()
 
-async def ycx(server: _Server, tier: int, event_id: Optional[int] = None) -> _Response:
+async def song_random(
+    main_server: ServerId,
+    fuzzy_search_result: Optional[FuzzySearchResult] = None,
+    text: Optional[str] = None
+) -> _Response:
+    '''随机歌曲
+
+    参数:
+        main_server (_ServerId): 主服务器
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
+
+    返回:
+        _Response: 响应信息
+    '''
+    
+    # 构建数据
+    data = {
+        'mainServer': main_server,
+        'useEasyBG': settings.use_easy_bg,
+        'compress': settings.compress
+    }
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
+    if text:
+        data['text'] = text
+    
+    # 发送请求
+    response = await Api(
+        settings.backend_url,
+        '/songRandom',
+        proxy=settings.backend_proxy
+    ).apost(data)
+    if isinstance(response, Response): return response.json()
+    return await response.json()
+
+@deprecated("The `ycx` api is now deprecated, use `cutoff_detail` instead.", category=None)
+async def ycx(server: Server, tier: int, event_id: Optional[int] = None) -> _Response:
     '''查询排行榜预测线
 
     参数:
@@ -410,28 +573,18 @@ async def ycx(server: _Server, tier: int, event_id: Optional[int] = None) -> _Re
     返回:
         _Response: 响应信息
     '''
+    warnings.warn(
+        "The `ycx` api is now deprecated, use `cutoff_detail` instead.",
+        DeprecationWarning
+    )
     
-    # 构建 URL
-    url = settings.backend_url + '/ycx'
+    if not isinstance(server, int):
+        raise ValueError("'server' must be an integer.")
     
-    # 构建数据
-    data = {
-        'server': server,
-        'tier': tier,
-        'compress': settings.compress
-    }
-    if event_id:
-        data['eventId'] = event_id
-    
-    # 发送请求
-    response = await Api(
-        url,
-        proxy=settings.backend_proxy
-    ).apost(data)
-    if isinstance(response, Response): return response.json()
-    return await response.json()
+    return await cutoff_detail(server, tier, event_id)
 
-async def ycx_all(server: _Server, event_id: Optional[int] = None) -> _Response:
+@deprecated("The `ycx_all` api is now deprecated, use `cutoff_all` instead.", category=None)
+async def ycx_all(server: Server, event_id: Optional[int] = None) -> _Response:
     '''查询全挡位预测线
 
     参数:
@@ -441,22 +594,12 @@ async def ycx_all(server: _Server, event_id: Optional[int] = None) -> _Response:
     返回:
         _Response: 响应信息
     '''
+    warnings.warn(
+        "The `ycx_all` api is now deprecated, use `cutoff_all` instead.",
+        DeprecationWarning
+    )
     
-    # 构建 URL
-    url = settings.backend_url + '/ycxAll'
+    if not isinstance(server, int):
+        raise ValueError("'server' must be an integer.")
     
-    # 构建数据
-    data = {
-        'server': server,
-        'compress': settings.compress
-    }
-    if event_id:
-        data['eventId'] = event_id
-    
-    # 发送请求
-    response = await Api(
-        url,
-        proxy=settings.backend_proxy
-    ).apost(data)
-    if isinstance(response, Response): return response.json()
-    return await response.json()
+    return await cutoff_all(server, event_id)
